@@ -442,11 +442,6 @@ class BuiltInFunction(BaseFunction):
 
     execute_print.arg_names = ["value"]
 
-    def execute_print_ret(self, exec_ctx):
-        return RTResult().success(String(str(exec_ctx.symbol_table.get("value"))))
-
-    execute_print_ret.arg_names = ["value"]
-
     def execute_input(self, exec_ctx):
         text = input()
         return RTResult().success(String(text))
@@ -610,7 +605,6 @@ class BuiltInFunction(BaseFunction):
 
 
 BuiltInFunction.print = BuiltInFunction("print")
-BuiltInFunction.print_ret = BuiltInFunction("print_ret")
 BuiltInFunction.input = BuiltInFunction("input")
 BuiltInFunction.input_int = BuiltInFunction("input_int")
 BuiltInFunction.append = BuiltInFunction("append")
